@@ -13,6 +13,7 @@ use crate::reporter::{
 };
 use crate::subcommand::{check_and_comment_on_pr, Command};
 use atty::Stream;
+use simplelog::CombinedLogger;
 use std::io;
 use std::process;
 use structopt::StructOpt;
@@ -50,22 +51,35 @@ struct Opt {
     /// Style of error reporting
     #[structopt(long, possible_values = &Reporter::variants(), case_insensitive = true)]
     reporter: Option<Reporter>,
+    #[structopt(long)]
+    /// Path to use in reporting for stdin
+    stdin_filepath: Option<String>,
     #[structopt(subcommand)]
     cmd: Option<Command>,
+    /// Enable debug logging output
+    #[structopt(long)]
+    verbose: bool,
 }
 
 fn main() {
     let opts = Opt::from_args();
+    if opts.verbose {
+        CombinedLogger::init(vec![simplelog::TermLogger::new(
+            simplelog::LevelFilter::Info,
+            simplelog::Config::default(),
+            simplelog::TerminalMode::Mixed,
+        )])
+        .expect("problem creating logger");
+    }
+
     let mut clap_app = Opt::clap();
     let stdout = io::stdout();
     let mut handle = stdout.lock();
 
     let is_stdin = !atty::is(Stream::Stdin);
     if let Some(subcommand) = opts.cmd {
-        match check_and_comment_on_pr(subcommand, is_stdin) {
-            Ok(exit_code) => {
-                process::exit(exit_code);
-            }
+        match check_and_comment_on_pr(subcommand, is_stdin, opts.stdin_filepath) {
+            Ok(_) => process::exit(0),
             Err(err) => {
                 eprintln!("{:#?}", err);
                 process::exit(1);
@@ -80,12 +94,16 @@ fn main() {
                 dump_ast_kind,
             ));
         } else {
-            match check_files(&opts.paths, is_stdin, opts.exclude) {
-                Ok(violations) => {
+            match check_files(&opts.paths, is_stdin, opts.stdin_filepath, opts.exclude) {
+                Ok(file_reports) => {
                     let reporter = opts.reporter.unwrap_or(Reporter::Tty);
-                    let exit_code = if !violations.is_empty() { 1 } else { 0 };
-                    match print_violations(&mut handle, violations, &reporter) {
+                    let total_violations = file_reports
+                        .iter()
+                        .map(|f| f.violations.len())
+                        .sum::<usize>();
+                    match print_violations(&mut handle, file_reports, &reporter) {
                         Ok(_) => {
+                            let exit_code = if total_violations > 0 { 1 } else { 0 };
                             process::exit(exit_code);
                         }
                         Err(e) => {
